/* Copyright: Jonathan Wright, 2001*/

/*          *****************
            *COMPLEX_FUNCS.C*
            *****************         */

#include "complex.h"

extern struct complex_method cpx;

/*--------------------------------------------------------------
Action: Calculate the objective function value for given vertex.

Author:J.A.Wright
Date:7-8-00
----------------------------------------------------------------*/
double calc_objective(double x[]){

double x_var[MAX_SEARCH_VAR],rtn;
int i_var;

/*Increment number of function calls*/

    ++cpx.n_func_calls;

/*De-scale variables*/

    for (i_var=0;i_var<cpx.n_var;i_var++)
        x_var[i_var] = cpx.x_lb[i_var] + x[i_var] *
                       (cpx.x_ub[i_var]-cpx.x_lb[i_var]);

/*Calculate the objective function value for x_var[]*/

    /*Objective == sum(x_var[]^2)*/
    rtn=0.0;
    for (i_var=0;i_var<cpx.n_var;i_var++) rtn+=x_var[i_var]*x_var[i_var];

return rtn;
}

/*--------------------------------------------------------
Action: Test the "implicit" constraints for infeasibility.

Author: J.A.Wright.
Date:7-8-00
----------------------------------------------------------*/
int test_constraints(double x[]){

double x_var[MAX_SEARCH_VAR];
int i_var;
double sum;

/*De-scale variables*/

    for (i_var=0;i_var<cpx.n_var;i_var++)
        x_var[i_var] = cpx.x_lb[i_var] + x[i_var] *
                       (cpx.x_ub[i_var]-cpx.x_lb[i_var]);

/*Constriant== sum(x_var)>=0.5*/

    sum=0.0;
    for (i_var=0;i_var<cpx.n_var;i_var++) sum+=x_var[i_var];
    if (sum<0.5) return INFEAS;

return FEAS;
}